@@ -1,5 +1,6 @@
 #include "nextclouddeckdialog.h"
 
+#include <QDesktopServices>
 #include <QMenu>
 #include <QShortcut>
 #include <QTimeZone>
@@ -19,10 +20,12 @@ NextcloudDeckDialog::NextcloudDeckDialog(QWidget *parent, bool listMode)
     setupUi();
     _currentCard = NextcloudDeckService::Card();
     ui->saveButton->setEnabled(false);
+    ui->archiveCardButton->setEnabled(false);
+    ui->deleteCardButton->setEnabled(false);
     ui->dueDateTimeCheckBox->setChecked(true);
     ui->newItemEdit->setFocus();
 
-    // Set default due date to one hour from now
+    // Set the default due date to one hour from now
     ui->dueDateTimeEdit->setDateTime(QDateTime::currentDateTime().addSecs(3600));
 
     // Hide currently unused UI elements
@@ -57,17 +60,9 @@ void NextcloudDeckDialog::setupUi() {
     insertAction->setIcon(QIcon::fromTheme(
         QStringLiteral("document-save"), QIcon(":icons/breeze-qownnotes/16x16/document-save.svg")));
     insertAction->setToolTip(
-        tr("Save the current todo item and insert a link"
-           " to it into the current note"));
+        tr("Save the current card item and insert a link to it into the current note"));
     //    connect(insertAction, SIGNAL(triggered()), this, SLOT(onSaveAndInsertButtonClicked()));
 
-    QAction *importAction = noteMenu->addAction(tr("Import as note"));
-    importAction->setIcon(
-        QIcon::fromTheme(QStringLiteral("document-import"),
-                         QIcon(":icons/breeze-qownnotes/16x16/document-import.svg")));
-    importAction->setToolTip(tr("Import the current todo item as new note"));
-    //    connect(importAction, SIGNAL(triggered()), this, SLOT(onImportAsNoteButtonClicked()));
-
     //    ui->noteButton->setMenu(noteMenu);
 
     // Clean up unused menu to prevent memory leak
@@ -115,9 +110,12 @@ void NextcloudDeckDialog::on_saveButton_clicked() {
             QStringLiteral("[%1](%2)").arg(title, nextcloudDeckService.getCardLinkForId(cardId));
 
 #ifndef INTEGRATION_TESTS
-        MainWindow *mainWindow = MainWindow::instance();
-        if (mainWindow != nullptr) {
-            mainWindow->activeNoteTextEdit()->insertPlainText(linkText);
+        // Only insert the link if we're creating a new card, not updating an existing one
+        if (cardIdToUpdate == -1) {
+            MainWindow *mainWindow = MainWindow::instance();
+            if (mainWindow != nullptr) {
+                mainWindow->activeNoteTextEdit()->insertPlainText(linkText);
+            }
         }
 #endif
 
@@ -128,6 +126,7 @@ void NextcloudDeckDialog::on_saveButton_clicked() {
         ui->newItemEdit->setFocus();
     }
 
+    // Close the dialog if we just created a new card and not updated an existing one
     if (cardIdToUpdate == -1) {
         close();
     }
@@ -236,24 +235,12 @@ void NextcloudDeckDialog::resetEditFrameControls() {
     ui->dueDateTimeCheckBox->setChecked(false);
     ui->dueDateTimeEdit->setEnabled(false);
     ui->saveButton->setEnabled(false);
+    ui->archiveCardButton->setEnabled(false);
+    ui->deleteCardButton->setEnabled(false);
     _currentCard = NextcloudDeckService::Card();
 }
 
-void NextcloudDeckDialog::on_cardItemTreeWidget_currentItemChanged(QTreeWidgetItem *current,
-                                                                   QTreeWidgetItem *previous) {
-    Q_UNUSED(previous)
-
-    // in case all items were removed
-    if (current == nullptr) {
-        resetEditFrameControls();
-        return;
-    }
-
-    MetricsService::instance()->sendVisitIfEnabled(QStringLiteral("deck/card/changed"));
-
-    int id = current->data(0, Qt::UserRole).toInt();
-
-    // Find the card in our hash using the ID
+void NextcloudDeckDialog::jumpToCard(int id) {
     if (_cards.contains(id)) {
         _currentCard = _cards[id];
 
@@ -269,12 +256,48 @@ void NextcloudDeckDialog::on_cardItemTreeWidget_currentItemChanged(QTreeWidgetIt
         }
 
         ui->saveButton->setEnabled(true);
+        ui->archiveCardButton->setEnabled(true);
+        ui->deleteCardButton->setEnabled(true);
         ui->editFrame->setEnabled(true);
     } else {
         resetEditFrameControls();
     }
 }
 
+void NextcloudDeckDialog::on_cardItemTreeWidget_currentItemChanged(QTreeWidgetItem *current,
+                                                                   QTreeWidgetItem *previous) {
+    Q_UNUSED(previous)
+
+    // in case all items were removed
+    if (current == nullptr) {
+        resetEditFrameControls();
+        return;
+    }
+
+    MetricsService::instance()->sendVisitIfEnabled(QStringLiteral("deck/card/changed"));
+
+    const int id = current->data(0, Qt::UserRole).toInt();
+
+    // Find the card in our hash using the ID
+    jumpToCard(id);
+}
+
+void NextcloudDeckDialog::setCardId(const int id) {
+    if (id < 1) {
+        return;
+    }
+
+    if (ui->cardItemTreeWidget->topLevelItemCount() == 0) {
+        reloadCardList();
+    }
+
+    const auto item = Utils::Gui::getTreeWidgetItemWithUserData(ui->cardItemTreeWidget, id);
+
+    if (item != nullptr) {
+        ui->cardItemTreeWidget->setCurrentItem(item);
+    }
+}
+
 void NextcloudDeckDialog::on_newItemEdit_textChanged(const QString &arg1) {
     Utils::Gui::searchForTextInTreeWidget(
         ui->cardItemTreeWidget, arg1,
@@ -287,7 +310,73 @@ void NextcloudDeckDialog::on_newItemEdit_returnPressed() {
     ui->titleLineEdit->setText(ui->newItemEdit->text());
     ui->descriptionTextEdit->setFocus();
     ui->newItemEdit->clear();
-    // Set default due date to one hour from now
+    // Set the default due date to one hour from now
     ui->dueDateTimeEdit->setDateTime(QDateTime::currentDateTime().addSecs(3600));
     ui->dueDateTimeCheckBox->setChecked(true);
 }
+
+void NextcloudDeckDialog::on_deleteCardButton_clicked() {
+    if (Utils::Gui::question(this, tr("Delete card"),
+                             tr("Do you want to delete the current Nextcloud Deck card?"),
+                             QStringLiteral("nextcloud-deck-delete")) != QMessageBox::Yes) {
+        return;
+    }
+
+    NextcloudDeckService nextcloudDeckService(this);
+    bool isSuccess = nextcloudDeckService.deleteCard(_currentCard.id);
+
+    if (isSuccess) {
+        reloadCardList();
+    }
+}
+
+void NextcloudDeckDialog::on_archiveCardButton_clicked() {
+    if (Utils::Gui::question(this, tr("Archive card"),
+                             tr("Do you want to archive the current Nextcloud Deck card?"),
+                             QStringLiteral("nextcloud-deck-archive")) != QMessageBox::Yes) {
+        return;
+    }
+
+    NextcloudDeckService nextcloudDeckService(this);
+    const bool isSuccess = nextcloudDeckService.archiveCard(_currentCard.id);
+
+    if (isSuccess) {
+        reloadCardList();
+    }
+}
+
+void NextcloudDeckDialog::openUrlInBrowserForItem(const QTreeWidgetItem *item) {
+    if (item == nullptr) {
+        return;
+    }
+
+    QDesktopServices::openUrl(
+        QUrl(NextcloudDeckService(this).getCardLinkForId(item->data(0, Qt::UserRole).toInt())));
+}
+
+void NextcloudDeckDialog::on_cardItemTreeWidget_itemDoubleClicked(QTreeWidgetItem *item,
+                                                                  int column) {
+    Q_UNUSED(column)
+
+    openUrlInBrowserForItem(item);
+}
+
+void NextcloudDeckDialog::on_cardItemTreeWidget_customContextMenuRequested(const QPoint &pos) {
+    const QPoint globalPos = ui->cardItemTreeWidget->mapToGlobal(pos);
+    QMenu menu;
+
+    QAction *openUrlAction = menu.addAction(tr("&Open card in browser"));
+    openUrlAction->setIcon(QIcon::fromTheme(QStringLiteral("text-html"),
+                                            QIcon(":icons/breeze-qownnotes/16x16/text-html.svg")));
+    QAction *selectedItem = menu.exec(globalPos);
+
+    if (selectedItem == nullptr) {
+        return;
+    }
+
+    QTreeWidgetItem *item = ui->cardItemTreeWidget->currentItem();
+
+    if (selectedItem == openUrlAction) {
+        openUrlInBrowserForItem(item);
+    }
+}
