@@ -1231,6 +1231,13 @@ bool QMarkdownTextEdit::openLinkAtCursorPosition() {
 
     if ((url.isValid() && isValidUrl(urlString)) || isRelativeFileUrl ||
         isLegacyAttachmentUrl) {
+        // Check if URL matches any ignored regular expressions
+        for (const QRegularExpression &regex : _ignoredClickUrlRegexps) {
+            if (regex.match(urlString).hasMatch()) {
+                return true; // URL matches ignored regex, don't open it
+            }
+        }
+
         // ignore some schemata
         if (!(_ignoredClickUrlSchemata.contains(url.scheme()) ||
               isRelativeFileUrl || isLegacyAttachmentUrl)) {
@@ -1288,13 +1295,22 @@ QPlainTextEditSearchWidget *QMarkdownTextEdit::searchWidget() {
 
 /**
  * @brief Sets url schemata that will be ignored when clicked on
- * @param urlSchemes
+ * @param ignoredUrlSchemata
  */
 void QMarkdownTextEdit::setIgnoredClickUrlSchemata(
     QStringList ignoredUrlSchemata) {
     _ignoredClickUrlSchemata = std::move(ignoredUrlSchemata);
 }
 
+/**
+ * @brief Sets url regular expressions that will be ignored when clicked on
+ * @param ignoredClickUrlRegexps
+ */
+void QMarkdownTextEdit::setIgnoredClickUrlRegexps(
+    QList<QRegularExpression> ignoredClickUrlRegexps) {
+    _ignoredClickUrlRegexps = std::move(ignoredClickUrlRegexps);
+}
+
 /**
  * @brief Returns a map of parsed Markdown urls with their link texts as key
  *
